extension-helpers
=================

.. image:: https://github.com/astropy/extension-helpers/actions/workflows/main.yml/badge.svg
  :target: https://github.com/astropy/extension-helpers/actions/workflows/main.yml

.. image:: https://codecov.io/gh/astropy/extension-helpers/branch/main/graph/badge.svg
  :target: https://codecov.io/gh/astropy/extension-helpers

.. image:: https://readthedocs.org/projects/extension-helpers/badge/?version=latest
  :target: https://extension-helpers.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

The **extension-helpers** package includes convenience helpers to assist with
building Python packages with compiled C/Cython extensions. It is developed by
the Astropy project but is intended to be general and usable by any Python
package.

For more information, see the documentation at http://extension-helpers.readthedocs.io
